# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 65.0.1-v202405012042
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ColumnRuleDescendantInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_index': 'int',
        'item_type': 'str',
        'property_match_operator': 'str',
        'property_name': 'str',
        'property_value': 'str'
    }

    attribute_map = {
        'column_index': 'columnIndex',
        'item_type': 'itemType',
        'property_match_operator': 'propertyMatchOperator',
        'property_name': 'propertyName',
        'property_value': 'propertyValue'
    }

    def __init__(self, column_index=None, item_type=None, property_match_operator=None, property_name=None, property_value=None):
        """
        ColumnRuleDescendantInputV1 - a model defined in Swagger
        """

        self._column_index = None
        self._item_type = None
        self._property_match_operator = None
        self._property_name = None
        self._property_value = None

        if column_index is not None:
          self.column_index = column_index
        if item_type is not None:
          self.item_type = item_type
        if property_match_operator is not None:
          self.property_match_operator = property_match_operator
        if property_name is not None:
          self.property_name = property_name
        if property_value is not None:
          self.property_value = property_value

    @property
    def column_index(self):
        """
        Gets the column_index of this ColumnRuleDescendantInputV1.
        The index of the column that references the item to search descendants for. The column index is 1-based

        :return: The column_index of this ColumnRuleDescendantInputV1.
        :rtype: int
        """
        return self._column_index

    @column_index.setter
    def column_index(self, column_index):
        """
        Sets the column_index of this ColumnRuleDescendantInputV1.
        The index of the column that references the item to search descendants for. The column index is 1-based

        :param column_index: The column_index of this ColumnRuleDescendantInputV1.
        :type: int
        """
        if column_index is None:
            raise ValueError("Invalid value for `column_index`, must not be `None`")

        self._column_index = column_index

    @property
    def item_type(self):
        """
        Gets the item_type of this ColumnRuleDescendantInputV1.
        The type of item to search for. If not specified, the rule will search for all item                         types. If specified, it must be a valid item type. For example, if the column references an Area,                          the itemType could be \"Asset\" to search for all assets under the area. If the column references                         an Asset, the itemType could be \"Condition\" to search for all conditions under the asset

        :return: The item_type of this ColumnRuleDescendantInputV1.
        :rtype: str
        """
        return self._item_type

    @item_type.setter
    def item_type(self, item_type):
        """
        Sets the item_type of this ColumnRuleDescendantInputV1.
        The type of item to search for. If not specified, the rule will search for all item                         types. If specified, it must be a valid item type. For example, if the column references an Area,                          the itemType could be \"Asset\" to search for all assets under the area. If the column references                         an Asset, the itemType could be \"Condition\" to search for all conditions under the asset

        :param item_type: The item_type of this ColumnRuleDescendantInputV1.
        :type: str
        """

        self._item_type = item_type

    @property
    def property_match_operator(self):
        """
        Gets the property_match_operator of this ColumnRuleDescendantInputV1.
        The operator to use for matching the property value. Available options are EQUALS, EQUALS_IGNORE_CASE, NOT_EQUALS, WITHIN and STRING_CONTAINS

        :return: The property_match_operator of this ColumnRuleDescendantInputV1.
        :rtype: str
        """
        return self._property_match_operator

    @property_match_operator.setter
    def property_match_operator(self, property_match_operator):
        """
        Sets the property_match_operator of this ColumnRuleDescendantInputV1.
        The operator to use for matching the property value. Available options are EQUALS, EQUALS_IGNORE_CASE, NOT_EQUALS, WITHIN and STRING_CONTAINS

        :param property_match_operator: The property_match_operator of this ColumnRuleDescendantInputV1.
        :type: str
        """
        if property_match_operator is None:
            raise ValueError("Invalid value for `property_match_operator`, must not be `None`")
        allowed_values = ["EQUALS", "EQUALS_IGNORE_CASE", "NOT_EQUALS", "WITHIN", "STRING_CONTAINS"]
        if property_match_operator not in allowed_values:
            raise ValueError(
                "Invalid value for `property_match_operator` ({0}), must be one of {1}"
                .format(property_match_operator, allowed_values)
            )

        self._property_match_operator = property_match_operator

    @property
    def property_name(self):
        """
        Gets the property_name of this ColumnRuleDescendantInputV1.
        The property name to search

        :return: The property_name of this ColumnRuleDescendantInputV1.
        :rtype: str
        """
        return self._property_name

    @property_name.setter
    def property_name(self, property_name):
        """
        Sets the property_name of this ColumnRuleDescendantInputV1.
        The property name to search

        :param property_name: The property_name of this ColumnRuleDescendantInputV1.
        :type: str
        """
        if property_name is None:
            raise ValueError("Invalid value for `property_name`, must not be `None`")

        self._property_name = property_name

    @property
    def property_value(self):
        """
        Gets the property_value of this ColumnRuleDescendantInputV1.
        The property value to search for

        :return: The property_value of this ColumnRuleDescendantInputV1.
        :rtype: str
        """
        return self._property_value

    @property_value.setter
    def property_value(self, property_value):
        """
        Sets the property_value of this ColumnRuleDescendantInputV1.
        The property value to search for

        :param property_value: The property_value of this ColumnRuleDescendantInputV1.
        :type: str
        """
        if property_value is None:
            raise ValueError("Invalid value for `property_value`, must not be `None`")

        self._property_value = property_value

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ColumnRuleDescendantInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 65.0.1-v202405012042
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class DateRangeInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'archived': 'bool',
        'background': 'bool',
        'condition_id': 'str',
        'cron_schedule': 'list[str]',
        'description': 'str',
        'enabled': 'bool',
        'formula': 'str',
        'name': 'str',
        'report_id': 'str'
    }

    attribute_map = {
        'archived': 'archived',
        'background': 'background',
        'condition_id': 'conditionId',
        'cron_schedule': 'cronSchedule',
        'description': 'description',
        'enabled': 'enabled',
        'formula': 'formula',
        'name': 'name',
        'report_id': 'reportId'
    }

    def __init__(self, archived=False, background=False, condition_id=None, cron_schedule=None, description=None, enabled=True, formula=None, name=None, report_id=None):
        """
        DateRangeInputV1 - a model defined in Swagger
        """

        self._archived = None
        self._background = None
        self._condition_id = None
        self._cron_schedule = None
        self._description = None
        self._enabled = None
        self._formula = None
        self._name = None
        self._report_id = None

        if archived is not None:
          self.archived = archived
        if background is not None:
          self.background = background
        if condition_id is not None:
          self.condition_id = condition_id
        if cron_schedule is not None:
          self.cron_schedule = cron_schedule
        if description is not None:
          self.description = description
        if enabled is not None:
          self.enabled = enabled
        if formula is not None:
          self.formula = formula
        if name is not None:
          self.name = name
        if report_id is not None:
          self.report_id = report_id

    @property
    def archived(self):
        """
        Gets the archived of this DateRangeInputV1.
        Whether the date range should be archived

        :return: The archived of this DateRangeInputV1.
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """
        Sets the archived of this DateRangeInputV1.
        Whether the date range should be archived

        :param archived: The archived of this DateRangeInputV1.
        :type: bool
        """

        self._archived = archived

    @property
    def background(self):
        """
        Gets the background of this DateRangeInputV1.
        Whether the date range, if scheduled, should continue to update if there are no subscribers (i.e. in the background)

        :return: The background of this DateRangeInputV1.
        :rtype: bool
        """
        return self._background

    @background.setter
    def background(self, background):
        """
        Sets the background of this DateRangeInputV1.
        Whether the date range, if scheduled, should continue to update if there are no subscribers (i.e. in the background)

        :param background: The background of this DateRangeInputV1.
        :type: bool
        """

        self._background = background

    @property
    def condition_id(self):
        """
        Gets the condition_id of this DateRangeInputV1.
        The date range's condition

        :return: The condition_id of this DateRangeInputV1.
        :rtype: str
        """
        return self._condition_id

    @condition_id.setter
    def condition_id(self, condition_id):
        """
        Sets the condition_id of this DateRangeInputV1.
        The date range's condition

        :param condition_id: The condition_id of this DateRangeInputV1.
        :type: str
        """

        self._condition_id = condition_id

    @property
    def cron_schedule(self):
        """
        Gets the cron_schedule of this DateRangeInputV1.
        The date range's update schedule as a cron expression (see http://www.quartz-scheduler.org/documentation/quartz-2.3.0/tutorials/crontrigger.html)

        :return: The cron_schedule of this DateRangeInputV1.
        :rtype: list[str]
        """
        return self._cron_schedule

    @cron_schedule.setter
    def cron_schedule(self, cron_schedule):
        """
        Sets the cron_schedule of this DateRangeInputV1.
        The date range's update schedule as a cron expression (see http://www.quartz-scheduler.org/documentation/quartz-2.3.0/tutorials/crontrigger.html)

        :param cron_schedule: The cron_schedule of this DateRangeInputV1.
        :type: list[str]
        """

        self._cron_schedule = cron_schedule

    @property
    def description(self):
        """
        Gets the description of this DateRangeInputV1.
        The date range's description

        :return: The description of this DateRangeInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DateRangeInputV1.
        The date range's description

        :param description: The description of this DateRangeInputV1.
        :type: str
        """

        self._description = description

    @property
    def enabled(self):
        """
        Gets the enabled of this DateRangeInputV1.
        Whether the date range is enabled to run jobs

        :return: The enabled of this DateRangeInputV1.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this DateRangeInputV1.
        Whether the date range is enabled to run jobs

        :param enabled: The enabled of this DateRangeInputV1.
        :type: bool
        """

        self._enabled = enabled

    @property
    def formula(self):
        """
        Gets the formula of this DateRangeInputV1.
        The date range's formula

        :return: The formula of this DateRangeInputV1.
        :rtype: str
        """
        return self._formula

    @formula.setter
    def formula(self, formula):
        """
        Sets the formula of this DateRangeInputV1.
        The date range's formula

        :param formula: The formula of this DateRangeInputV1.
        :type: str
        """
        if formula is None:
            raise ValueError("Invalid value for `formula`, must not be `None`")

        self._formula = formula

    @property
    def name(self):
        """
        Gets the name of this DateRangeInputV1.
        The date range's name

        :return: The name of this DateRangeInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DateRangeInputV1.
        The date range's name

        :param name: The name of this DateRangeInputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def report_id(self):
        """
        Gets the report_id of this DateRangeInputV1.
        The date range's report

        :return: The report_id of this DateRangeInputV1.
        :rtype: str
        """
        return self._report_id

    @report_id.setter
    def report_id(self, report_id):
        """
        Sets the report_id of this DateRangeInputV1.
        The date range's report

        :param report_id: The report_id of this DateRangeInputV1.
        :type: str
        """

        self._report_id = report_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, DateRangeInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 65.0.1-v202405012042
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class WorkbookInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'branch_from': 'str',
        'description': 'str',
        'folder_id': 'str',
        'name': 'str',
        'owner_id': 'str',
        'type': 'str'
    }

    attribute_map = {
        'branch_from': 'branchFrom',
        'description': 'description',
        'folder_id': 'folderId',
        'name': 'name',
        'owner_id': 'ownerId',
        'type': 'type'
    }

    def __init__(self, branch_from=None, description=None, folder_id=None, name=None, owner_id=None, type=None):
        """
        WorkbookInputV1 - a model defined in Swagger
        """

        self._branch_from = None
        self._description = None
        self._folder_id = None
        self._name = None
        self._owner_id = None
        self._type = None

        if branch_from is not None:
          self.branch_from = branch_from
        if description is not None:
          self.description = description
        if folder_id is not None:
          self.folder_id = folder_id
        if name is not None:
          self.name = name
        if owner_id is not None:
          self.owner_id = owner_id
        if type is not None:
          self.type = type

    @property
    def branch_from(self):
        """
        Gets the branch_from of this WorkbookInputV1.
        Create a new workbook by duplicating the contents and history of the workbook with the specified ID. When null, no branching will occur; resulting workbook will be empty.

        :return: The branch_from of this WorkbookInputV1.
        :rtype: str
        """
        return self._branch_from

    @branch_from.setter
    def branch_from(self, branch_from):
        """
        Sets the branch_from of this WorkbookInputV1.
        Create a new workbook by duplicating the contents and history of the workbook with the specified ID. When null, no branching will occur; resulting workbook will be empty.

        :param branch_from: The branch_from of this WorkbookInputV1.
        :type: str
        """

        self._branch_from = branch_from

    @property
    def description(self):
        """
        Gets the description of this WorkbookInputV1.
        Clarifying information or other plain language description of this item. An input of just whitespaces is equivalent to a null input.

        :return: The description of this WorkbookInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this WorkbookInputV1.
        Clarifying information or other plain language description of this item. An input of just whitespaces is equivalent to a null input.

        :param description: The description of this WorkbookInputV1.
        :type: str
        """

        self._description = description

    @property
    def folder_id(self):
        """
        Gets the folder_id of this WorkbookInputV1.
        The id of the folder to place the new workbook into. Special values of 'mine' or 'corporate' to place the item in the authenticated user's home folder or the corporate folder, respectively. If null, the workbook will be created in the authenticated user's home folder.

        :return: The folder_id of this WorkbookInputV1.
        :rtype: str
        """
        return self._folder_id

    @folder_id.setter
    def folder_id(self, folder_id):
        """
        Sets the folder_id of this WorkbookInputV1.
        The id of the folder to place the new workbook into. Special values of 'mine' or 'corporate' to place the item in the authenticated user's home folder or the corporate folder, respectively. If null, the workbook will be created in the authenticated user's home folder.

        :param folder_id: The folder_id of this WorkbookInputV1.
        :type: str
        """

        self._folder_id = folder_id

    @property
    def name(self):
        """
        Gets the name of this WorkbookInputV1.
        Human readable name. Required during creation. An input of just whitespaces is equivalent to a null input.

        :return: The name of this WorkbookInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this WorkbookInputV1.
        Human readable name. Required during creation. An input of just whitespaces is equivalent to a null input.

        :param name: The name of this WorkbookInputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def owner_id(self):
        """
        Gets the owner_id of this WorkbookInputV1.
        The ID of the User that owns this workbook. If omitted when creating a new Workbook, the authenticated user is used by default. Only administrators may set this value.

        :return: The owner_id of this WorkbookInputV1.
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """
        Sets the owner_id of this WorkbookInputV1.
        The ID of the User that owns this workbook. If omitted when creating a new Workbook, the authenticated user is used by default. Only administrators may set this value.

        :param owner_id: The owner_id of this WorkbookInputV1.
        :type: str
        """

        self._owner_id = owner_id

    @property
    def type(self):
        """
        Gets the type of this WorkbookInputV1.
        The type of workbook, either 'Analysis' or 'Topic'. Defaults to 'Analysis'.

        :return: The type of this WorkbookInputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this WorkbookInputV1.
        The type of workbook, either 'Analysis' or 'Topic'. Defaults to 'Analysis'.

        :param type: The type of this WorkbookInputV1.
        :type: str
        """

        self._type = type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, WorkbookInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 65.0.1-v202405012042
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class DatasourceStatisticsV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'median_datasource_nanos': 'int',
        'median_queue_nanos': 'int',
        'median_total_nanos': 'int',
        'most_recent_cancellation': 'str',
        'most_recent_failure': 'str',
        'most_recent_success': 'str',
        'most_recent_timeout': 'str',
        'num_cancellations': 'int',
        'num_failures': 'int',
        'num_successes': 'int',
        'num_timeouts': 'int',
        'total_num_datums': 'int'
    }

    attribute_map = {
        'median_datasource_nanos': 'medianDatasourceNanos',
        'median_queue_nanos': 'medianQueueNanos',
        'median_total_nanos': 'medianTotalNanos',
        'most_recent_cancellation': 'mostRecentCancellation',
        'most_recent_failure': 'mostRecentFailure',
        'most_recent_success': 'mostRecentSuccess',
        'most_recent_timeout': 'mostRecentTimeout',
        'num_cancellations': 'numCancellations',
        'num_failures': 'numFailures',
        'num_successes': 'numSuccesses',
        'num_timeouts': 'numTimeouts',
        'total_num_datums': 'totalNumDatums'
    }

    def __init__(self, median_datasource_nanos=None, median_queue_nanos=None, median_total_nanos=None, most_recent_cancellation=None, most_recent_failure=None, most_recent_success=None, most_recent_timeout=None, num_cancellations=None, num_failures=None, num_successes=None, num_timeouts=None, total_num_datums=None):
        """
        DatasourceStatisticsV1 - a model defined in Swagger
        """

        self._median_datasource_nanos = None
        self._median_queue_nanos = None
        self._median_total_nanos = None
        self._most_recent_cancellation = None
        self._most_recent_failure = None
        self._most_recent_success = None
        self._most_recent_timeout = None
        self._num_cancellations = None
        self._num_failures = None
        self._num_successes = None
        self._num_timeouts = None
        self._total_num_datums = None

        if median_datasource_nanos is not None:
          self.median_datasource_nanos = median_datasource_nanos
        if median_queue_nanos is not None:
          self.median_queue_nanos = median_queue_nanos
        if median_total_nanos is not None:
          self.median_total_nanos = median_total_nanos
        if most_recent_cancellation is not None:
          self.most_recent_cancellation = most_recent_cancellation
        if most_recent_failure is not None:
          self.most_recent_failure = most_recent_failure
        if most_recent_success is not None:
          self.most_recent_success = most_recent_success
        if most_recent_timeout is not None:
          self.most_recent_timeout = most_recent_timeout
        if num_cancellations is not None:
          self.num_cancellations = num_cancellations
        if num_failures is not None:
          self.num_failures = num_failures
        if num_successes is not None:
          self.num_successes = num_successes
        if num_timeouts is not None:
          self.num_timeouts = num_timeouts
        if total_num_datums is not None:
          self.total_num_datums = total_num_datums

    @property
    def median_datasource_nanos(self):
        """
        Gets the median_datasource_nanos of this DatasourceStatisticsV1.
        The median duration that recent requests to this datasource spend running at the connector, in nanoseconds. If there were no recent requests, the value will be reported as 0.

        :return: The median_datasource_nanos of this DatasourceStatisticsV1.
        :rtype: int
        """
        return self._median_datasource_nanos

    @median_datasource_nanos.setter
    def median_datasource_nanos(self, median_datasource_nanos):
        """
        Sets the median_datasource_nanos of this DatasourceStatisticsV1.
        The median duration that recent requests to this datasource spend running at the connector, in nanoseconds. If there were no recent requests, the value will be reported as 0.

        :param median_datasource_nanos: The median_datasource_nanos of this DatasourceStatisticsV1.
        :type: int
        """

        self._median_datasource_nanos = median_datasource_nanos

    @property
    def median_queue_nanos(self):
        """
        Gets the median_queue_nanos of this DatasourceStatisticsV1.
        The median duration that recent requests to this datasource spend in a queue at the connector, in nanoseconds. If there were no recent requests, the value will be reported as 0.

        :return: The median_queue_nanos of this DatasourceStatisticsV1.
        :rtype: int
        """
        return self._median_queue_nanos

    @median_queue_nanos.setter
    def median_queue_nanos(self, median_queue_nanos):
        """
        Sets the median_queue_nanos of this DatasourceStatisticsV1.
        The median duration that recent requests to this datasource spend in a queue at the connector, in nanoseconds. If there were no recent requests, the value will be reported as 0.

        :param median_queue_nanos: The median_queue_nanos of this DatasourceStatisticsV1.
        :type: int
        """

        self._median_queue_nanos = median_queue_nanos

    @property
    def median_total_nanos(self):
        """
        Gets the median_total_nanos of this DatasourceStatisticsV1.
        The median duration that recent requests to this datasource spend running in total, from the perspective of the Seeq server. This measurement includes network latency to the agent/connector, queueing on the agent/connector, and processing on the agent/connector. If there were no recent requests, the value will be reported as 0.

        :return: The median_total_nanos of this DatasourceStatisticsV1.
        :rtype: int
        """
        return self._median_total_nanos

    @median_total_nanos.setter
    def median_total_nanos(self, median_total_nanos):
        """
        Sets the median_total_nanos of this DatasourceStatisticsV1.
        The median duration that recent requests to this datasource spend running in total, from the perspective of the Seeq server. This measurement includes network latency to the agent/connector, queueing on the agent/connector, and processing on the agent/connector. If there were no recent requests, the value will be reported as 0.

        :param median_total_nanos: The median_total_nanos of this DatasourceStatisticsV1.
        :type: int
        """

        self._median_total_nanos = median_total_nanos

    @property
    def most_recent_cancellation(self):
        """
        Gets the most_recent_cancellation of this DatasourceStatisticsV1.
        The time of the most recent cancelled request, in ISO-8601 format

        :return: The most_recent_cancellation of this DatasourceStatisticsV1.
        :rtype: str
        """
        return self._most_recent_cancellation

    @most_recent_cancellation.setter
    def most_recent_cancellation(self, most_recent_cancellation):
        """
        Sets the most_recent_cancellation of this DatasourceStatisticsV1.
        The time of the most recent cancelled request, in ISO-8601 format

        :param most_recent_cancellation: The most_recent_cancellation of this DatasourceStatisticsV1.
        :type: str
        """

        self._most_recent_cancellation = most_recent_cancellation

    @property
    def most_recent_failure(self):
        """
        Gets the most_recent_failure of this DatasourceStatisticsV1.
        The time of the most recent failed request, in ISO-8601 format

        :return: The most_recent_failure of this DatasourceStatisticsV1.
        :rtype: str
        """
        return self._most_recent_failure

    @most_recent_failure.setter
    def most_recent_failure(self, most_recent_failure):
        """
        Sets the most_recent_failure of this DatasourceStatisticsV1.
        The time of the most recent failed request, in ISO-8601 format

        :param most_recent_failure: The most_recent_failure of this DatasourceStatisticsV1.
        :type: str
        """

        self._most_recent_failure = most_recent_failure

    @property
    def most_recent_success(self):
        """
        Gets the most_recent_success of this DatasourceStatisticsV1.
        The time of the most recent successful request, in ISO-8601 format

        :return: The most_recent_success of this DatasourceStatisticsV1.
        :rtype: str
        """
        return self._most_recent_success

    @most_recent_success.setter
    def most_recent_success(self, most_recent_success):
        """
        Sets the most_recent_success of this DatasourceStatisticsV1.
        The time of the most recent successful request, in ISO-8601 format

        :param most_recent_success: The most_recent_success of this DatasourceStatisticsV1.
        :type: str
        """

        self._most_recent_success = most_recent_success

    @property
    def most_recent_timeout(self):
        """
        Gets the most_recent_timeout of this DatasourceStatisticsV1.
        The time of the most recent timed-out request, in ISO-8601 format

        :return: The most_recent_timeout of this DatasourceStatisticsV1.
        :rtype: str
        """
        return self._most_recent_timeout

    @most_recent_timeout.setter
    def most_recent_timeout(self, most_recent_timeout):
        """
        Sets the most_recent_timeout of this DatasourceStatisticsV1.
        The time of the most recent timed-out request, in ISO-8601 format

        :param most_recent_timeout: The most_recent_timeout of this DatasourceStatisticsV1.
        :type: str
        """

        self._most_recent_timeout = most_recent_timeout

    @property
    def num_cancellations(self):
        """
        Gets the num_cancellations of this DatasourceStatisticsV1.
        Total number of cancelled requests to this datasource since the last restart of Seeq server.

        :return: The num_cancellations of this DatasourceStatisticsV1.
        :rtype: int
        """
        return self._num_cancellations

    @num_cancellations.setter
    def num_cancellations(self, num_cancellations):
        """
        Sets the num_cancellations of this DatasourceStatisticsV1.
        Total number of cancelled requests to this datasource since the last restart of Seeq server.

        :param num_cancellations: The num_cancellations of this DatasourceStatisticsV1.
        :type: int
        """

        self._num_cancellations = num_cancellations

    @property
    def num_failures(self):
        """
        Gets the num_failures of this DatasourceStatisticsV1.
        Total number of failed requests to this datasource since the last restart of Seeq server.

        :return: The num_failures of this DatasourceStatisticsV1.
        :rtype: int
        """
        return self._num_failures

    @num_failures.setter
    def num_failures(self, num_failures):
        """
        Sets the num_failures of this DatasourceStatisticsV1.
        Total number of failed requests to this datasource since the last restart of Seeq server.

        :param num_failures: The num_failures of this DatasourceStatisticsV1.
        :type: int
        """

        self._num_failures = num_failures

    @property
    def num_successes(self):
        """
        Gets the num_successes of this DatasourceStatisticsV1.
        Total number of successful requests to this datasource since the last restart of Seeq server.

        :return: The num_successes of this DatasourceStatisticsV1.
        :rtype: int
        """
        return self._num_successes

    @num_successes.setter
    def num_successes(self, num_successes):
        """
        Sets the num_successes of this DatasourceStatisticsV1.
        Total number of successful requests to this datasource since the last restart of Seeq server.

        :param num_successes: The num_successes of this DatasourceStatisticsV1.
        :type: int
        """

        self._num_successes = num_successes

    @property
    def num_timeouts(self):
        """
        Gets the num_timeouts of this DatasourceStatisticsV1.
        Total number of timed-out requests to this datasource since the last restart of Seeq server.

        :return: The num_timeouts of this DatasourceStatisticsV1.
        :rtype: int
        """
        return self._num_timeouts

    @num_timeouts.setter
    def num_timeouts(self, num_timeouts):
        """
        Sets the num_timeouts of this DatasourceStatisticsV1.
        Total number of timed-out requests to this datasource since the last restart of Seeq server.

        :param num_timeouts: The num_timeouts of this DatasourceStatisticsV1.
        :type: int
        """

        self._num_timeouts = num_timeouts

    @property
    def total_num_datums(self):
        """
        Gets the total_num_datums of this DatasourceStatisticsV1.
        Total number of datums (i.e, samples, capsules, or rows) that were received in response to requests to this datasource since the last restart of Seeq server.

        :return: The total_num_datums of this DatasourceStatisticsV1.
        :rtype: int
        """
        return self._total_num_datums

    @total_num_datums.setter
    def total_num_datums(self, total_num_datums):
        """
        Sets the total_num_datums of this DatasourceStatisticsV1.
        Total number of datums (i.e, samples, capsules, or rows) that were received in response to requests to this datasource since the last restart of Seeq server.

        :param total_num_datums: The total_num_datums of this DatasourceStatisticsV1.
        :type: int
        """

        self._total_num_datums = total_num_datums

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, DatasourceStatisticsV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 65.0.1-v202405012042
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class GetSamplesOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'continuation_token': 'str',
        'key_unit_of_measure': 'str',
        'limit': 'int',
        'next': 'str',
        'samples': 'list[SampleOutputV1]',
        'status_message': 'str',
        'value_unit_of_measure': 'str',
        'warning_count': 'int',
        'warning_logs': 'list[FormulaLogV1]'
    }

    attribute_map = {
        'continuation_token': 'continuationToken',
        'key_unit_of_measure': 'keyUnitOfMeasure',
        'limit': 'limit',
        'next': 'next',
        'samples': 'samples',
        'status_message': 'statusMessage',
        'value_unit_of_measure': 'valueUnitOfMeasure',
        'warning_count': 'warningCount',
        'warning_logs': 'warningLogs'
    }

    def __init__(self, continuation_token=None, key_unit_of_measure=None, limit=None, next=None, samples=None, status_message=None, value_unit_of_measure=None, warning_count=None, warning_logs=None):
        """
        GetSamplesOutputV1 - a model defined in Swagger
        """

        self._continuation_token = None
        self._key_unit_of_measure = None
        self._limit = None
        self._next = None
        self._samples = None
        self._status_message = None
        self._value_unit_of_measure = None
        self._warning_count = None
        self._warning_logs = None

        if continuation_token is not None:
          self.continuation_token = continuation_token
        if key_unit_of_measure is not None:
          self.key_unit_of_measure = key_unit_of_measure
        if limit is not None:
          self.limit = limit
        if next is not None:
          self.next = next
        if samples is not None:
          self.samples = samples
        if status_message is not None:
          self.status_message = status_message
        if value_unit_of_measure is not None:
          self.value_unit_of_measure = value_unit_of_measure
        if warning_count is not None:
          self.warning_count = warning_count
        if warning_logs is not None:
          self.warning_logs = warning_logs

    @property
    def continuation_token(self):
        """
        Gets the continuation_token of this GetSamplesOutputV1.
        A token that can be used to fetch the next page of results. Submit the same query with the continuationToken set to this returned value. Null if all results have been returned.

        :return: The continuation_token of this GetSamplesOutputV1.
        :rtype: str
        """
        return self._continuation_token

    @continuation_token.setter
    def continuation_token(self, continuation_token):
        """
        Sets the continuation_token of this GetSamplesOutputV1.
        A token that can be used to fetch the next page of results. Submit the same query with the continuationToken set to this returned value. Null if all results have been returned.

        :param continuation_token: The continuation_token of this GetSamplesOutputV1.
        :type: str
        """

        self._continuation_token = continuation_token

    @property
    def key_unit_of_measure(self):
        """
        Gets the key_unit_of_measure of this GetSamplesOutputV1.
        The unit of measure for the signal's keys. A time-keyed signal has key units of 'ns'.

        :return: The key_unit_of_measure of this GetSamplesOutputV1.
        :rtype: str
        """
        return self._key_unit_of_measure

    @key_unit_of_measure.setter
    def key_unit_of_measure(self, key_unit_of_measure):
        """
        Sets the key_unit_of_measure of this GetSamplesOutputV1.
        The unit of measure for the signal's keys. A time-keyed signal has key units of 'ns'.

        :param key_unit_of_measure: The key_unit_of_measure of this GetSamplesOutputV1.
        :type: str
        """

        self._key_unit_of_measure = key_unit_of_measure

    @property
    def limit(self):
        """
        Gets the limit of this GetSamplesOutputV1.
        The pagination limit, the maximum number of collection items that will be returned in this page of results. Fewer than the limit may be returned if more datums do not exist or if many datums share the same key.

        :return: The limit of this GetSamplesOutputV1.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """
        Sets the limit of this GetSamplesOutputV1.
        The pagination limit, the maximum number of collection items that will be returned in this page of results. Fewer than the limit may be returned if more datums do not exist or if many datums share the same key.

        :param limit: The limit of this GetSamplesOutputV1.
        :type: int
        """

        self._limit = limit

    @property
    def next(self):
        """
        Gets the next of this GetSamplesOutputV1.
        The href of the next set of paginated results

        :return: The next of this GetSamplesOutputV1.
        :rtype: str
        """
        return self._next

    @next.setter
    def next(self, next):
        """
        Sets the next of this GetSamplesOutputV1.
        The href of the next set of paginated results

        :param next: The next of this GetSamplesOutputV1.
        :type: str
        """

        self._next = next

    @property
    def samples(self):
        """
        Gets the samples of this GetSamplesOutputV1.
        The samples in the signal

        :return: The samples of this GetSamplesOutputV1.
        :rtype: list[SampleOutputV1]
        """
        return self._samples

    @samples.setter
    def samples(self, samples):
        """
        Sets the samples of this GetSamplesOutputV1.
        The samples in the signal

        :param samples: The samples of this GetSamplesOutputV1.
        :type: list[SampleOutputV1]
        """

        self._samples = samples

    @property
    def status_message(self):
        """
        Gets the status_message of this GetSamplesOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation. Null if the status message has not been set.

        :return: The status_message of this GetSamplesOutputV1.
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """
        Sets the status_message of this GetSamplesOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation. Null if the status message has not been set.

        :param status_message: The status_message of this GetSamplesOutputV1.
        :type: str
        """

        self._status_message = status_message

    @property
    def value_unit_of_measure(self):
        """
        Gets the value_unit_of_measure of this GetSamplesOutputV1.
        The unit of measure for the signal's values

        :return: The value_unit_of_measure of this GetSamplesOutputV1.
        :rtype: str
        """
        return self._value_unit_of_measure

    @value_unit_of_measure.setter
    def value_unit_of_measure(self, value_unit_of_measure):
        """
        Sets the value_unit_of_measure of this GetSamplesOutputV1.
        The unit of measure for the signal's values

        :param value_unit_of_measure: The value_unit_of_measure of this GetSamplesOutputV1.
        :type: str
        """

        self._value_unit_of_measure = value_unit_of_measure

    @property
    def warning_count(self):
        """
        Gets the warning_count of this GetSamplesOutputV1.
        The total number of warnings that have occurred

        :return: The warning_count of this GetSamplesOutputV1.
        :rtype: int
        """
        return self._warning_count

    @warning_count.setter
    def warning_count(self, warning_count):
        """
        Sets the warning_count of this GetSamplesOutputV1.
        The total number of warnings that have occurred

        :param warning_count: The warning_count of this GetSamplesOutputV1.
        :type: int
        """

        self._warning_count = warning_count

    @property
    def warning_logs(self):
        """
        Gets the warning_logs of this GetSamplesOutputV1.
        The Formula warning logs, which includes the text, line number, and column number where the warning occurred in addition to the warning details

        :return: The warning_logs of this GetSamplesOutputV1.
        :rtype: list[FormulaLogV1]
        """
        return self._warning_logs

    @warning_logs.setter
    def warning_logs(self, warning_logs):
        """
        Sets the warning_logs of this GetSamplesOutputV1.
        The Formula warning logs, which includes the text, line number, and column number where the warning occurred in addition to the warning details

        :param warning_logs: The warning_logs of this GetSamplesOutputV1.
        :type: list[FormulaLogV1]
        """

        self._warning_logs = warning_logs

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, GetSamplesOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
